@@ -351,10 +351,129 @@ function create_filter_rule () {
     fi
 }
 
+"""
+        self.procfunctions = """
+function escape_dots () 
+{
+
+    local result="${1//./\\\\.}"
+    echo "$result"
+
+}
+
+function regex_build () {
+
+    escape_setting=$(escape_dots $1)
+    regex_result="^([^\S\\r\\n]|#|)+($escape_setting)([^\S\\r\\n]|[0-9]|#|[a-zA-Z])+$"
+    echo $regex_result
+}
+
+function proc_string_build () {
+
+    local alldevices=$(ls /proc/sys/net/ipv6/conf | tr -s ' ')
+    local devices=$alldevices
+    local array_devices=($devices)
+    declare -a array_proc_strings
+    for x in "${array_devices[@]}"; do
+       array_proc_strings+=("net.ipv6.conf."$x".disable_ipv6")
+    done
+    echo ${array_proc_strings[@]}
+}
+
+function sysproc_string_build () {
+
+    local alldevices=$(ls /proc/sys/net/ipv6/conf | tr -s ' ')
+    local devices=$alldevices
+    local array_devices=($devices)
+    declare -a array_sysproc_strings
+    for x in "${array_devices[@]}"; do
+        #echo $x
+        local procstring="/proc/sys/net/ipv6/conf/"$x"/disable_ipv6"
+        #echo $procstring
+        array_sysproc_strings+=($procstring)
+    done
+    echo ${array_sysproc_strings[@]}
+
+}
+
+function check_for_proc_string () {
+
+    local mycount=$(grep -Po $1 /etc/sysctl.conf | wc -l)
+    echo $mycount
+}
+
+function delete_proc_string () {
+    deletecommand="sed -i -E '/$1/d' /etc/sysctl.conf"
+    eval $deletecommand
+}
+
+function disable_proc_string () {
+    proc_string_disable=$1" 1"
+    echo $proc_string_disable >> /etc/sysctl.conf
+}
+
+function enable_proc_string () {
+    proc_string_enable=$1" 0"
+    echo $proc_string_enable >> /etc/sysctl.conf
+
+}
+
+function sysctl_proc_disable_ipv6 () {
+    array_sysproc_string_build=$(sysproc_string_build)
+    for sysproc_string in $array_sysproc_string_build; do
+        sysproc_disable_command="echo 1 > $sysproc_string"
+        #echo $sysproc_disable_command
+        eval $sysproc_disable_command
+    done
+}
+
+function sysctl_proc_enable_ipv6 () {
+    array_sysproc_string_build=$(sysproc_string_build)
+    for sysproc_string in $array_sysproc_string_build; do
+        sysproc_enable_command="echo 0 > $sysproc_string"
+        #echo $sysproc_enable_command
+        eval $sysproc_enable_command
+    done
+}
+
+function sysctl_file_disable_ipv6 () {
+    array_proc_strings=$(proc_string_build)
+    for proc_string in $array_proc_strings; do
+        proc_string_regex=$(regex_build $proc_string)
+        proc_string_count=$(check_for_proc_string $proc_string_regex)
+        if [ $proc_string_count -gt 0 ]; then
+            #echo "Setting '$proc_string' FOUND. Deleting..."
+            delete_proc_string $proc_string_regex
+            disable_proc_string $proc_string
+        else
+            #echo "Setting '$proc_string' NOT found."
+            disable_proc_string $proc_string
+        fi
+    done
+    sysctl_proc_disable_ipv6
+}
+
+function sysctl_file_enable_ipv6 () {
+    array_proc_strings=$(proc_string_build)
+    for proc_string in $array_proc_strings; do
+        proc_string_regex=$(regex_build $proc_string)
+        proc_string_count=$(check_for_proc_string $proc_string_regex)
+        if [ $proc_string_count -gt 0 ]; then
+            echo "Setting '$proc_string' FOUND. Deleting..."
+            delete_proc_string $proc_string_regex
+            enable_proc_string $proc_string
+        else
+            echo "Setting '$proc_string' NOT found."
+            enable_proc_string $proc_string
+        fi
+    done
+    sysctl_proc_enable_ipv6
+}        
 """
 
     def nuke_text(self):
-        text = """#!/bin/bash
+        text = f"""#!/bin/bash
+{self.procfunctions}
 #Flush all chains, delete custom chains.
 iptables -F
 iptables -X
@@ -364,11 +483,13 @@ iptables -t nat -X
 iptables --policy INPUT ACCEPT
 iptables --policy FORWARD ACCEPT
 iptables --policy OUTPUT ACCEPT 
-        """
+sysctl_file_enable_ipv6
+"""
         return self.systemdfilepaths.nuke_bash, text
 
     def off_text(self):
-        text = """#!/bin/bash
+        text = f"""#!/bin/bash
+{self.procfunctions}
 #Block all traffic as default.
 iptables --policy INPUT ACCEPT
 iptables --policy FORWARD ACCEPT
@@ -377,11 +498,13 @@ echo "off-D"
 iptables -D INPUT -j RB_RELATED_AND_ESTABLISHED
 iptables -D OUTPUT -j RB_OUTPUT_VPN_KILL_SWITCH
 iptables -D DOCKER-USER -j RB_DOCKER_VPN_KILL_SWITCH
-        """
+sysctl_file_enable_ipv6
+"""
         return self.systemdfilepaths.off_bash, text
 
     def flush_text(self):
-        text = """#!/bin/bash
+        text = f"""#!/bin/bash
+{self.procfunctions}
 #Block all traffic as default.
 iptables --policy INPUT ACCEPT
 iptables --policy FORWARD ACCEPT
@@ -398,12 +521,14 @@ echo "flush-D"
 iptables --delete-chain RB_RELATED_AND_ESTABLISHED
 iptables --delete-chain RB_OUTPUT_VPN_KILL_SWITCH
 iptables --delete-chain RB_DOCKER_VPN_KILL_SWITCH
-        """
+sysctl_file_enable_ipv6
+"""
         return self.systemdfilepaths.flush_bash, text
 
     def protect_text(self):
         text = f"""#!/bin/bash
 {self.bashfunctions}
+{self.procfunctions}
 #Block all traffic as default.
 iptables --policy INPUT DROP
 iptables --policy FORWARD DROP
@@ -411,12 +536,14 @@ iptables --policy OUTPUT ACCEPT
 create_filter_chain 'RB_RELATED_AND_ESTABLISHED'
 create_filter_rule 'iptables -A RB_RELATED_AND_ESTABLISHED -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
 create_filter_rule 'iptables -I INPUT -j RB_RELATED_AND_ESTABLISHED'
+sysctl_file_disable_ipv6
 """
         return self.systemdfilepaths.protect_bash, text
 
     def vpnkillswitch_text(self):
         text = f"""#!/bin/bash
 {self.bashfunctions}
+{self.procfunctions}
 #Block all traffic as default.
 iptables --policy INPUT DROP
 iptables --policy FORWARD DROP
@@ -439,12 +566,14 @@ create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -d 10.0.0.0/8 -j ACCEP
 #create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -d 10.17.0.1 -j ACCEPT'
 #let's pop a reroute to our vpn rules at the top of the OUTPUT chain using -I insert
 create_filter_rule 'iptables -I OUTPUT  -j RB_OUTPUT_VPN_KILL_SWITCH'
+sysctl_file_disable_ipv6
 """
         return self.systemdfilepaths.vpn4_bash, text
 
     def vpnkillswitch_g_text(self):
         text = f"""#!/bin/bash
 {self.bashfunctions}
+{self.procfunctions}
 #Block all traffic as default.
 iptables --policy INPUT DROP
 iptables --policy FORWARD DROP
@@ -482,23 +611,27 @@ create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -d 10.0.0.0/8 -j ACCEP
 #create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -d 10.17.0.1 -j ACCEPT'
 #let's pop a reroute to our vpn rules at the top of the OUTPUT chain using -I insert
 create_filter_rule 'iptables -I OUTPUT -j RB_OUTPUT_VPN_KILL_SWITCH'
+sysctl_file_disable_ipv6
 """
         return self.systemdfilepaths.vpn4_bash, text
 
     def dockerkillswitch_text(self):
         text = f"""#!/bin/bash
 {self.bashfunctions}
+{self.procfunctions}
 create_filter_chain 'RB_DOCKER_VPN_KILL_SWITCH'
 create_filter_rule 'iptables -A RB_DOCKER_VPN_KILL_SWITCH -o tun+ -j ACCEPT'
 create_filter_rule 'iptables -A RB_DOCKER_VPN_KILL_SWITCH -i tun+ -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
 create_filter_rule 'iptables -A RB_DOCKER_VPN_KILL_SWITCH -j DROP'
 create_filter_rule 'iptables -I DOCKER-USER  -j RB_DOCKER_VPN_KILL_SWITCH'
+sysctl_file_disable_ipv6
 """
         return self.systemdfilepaths.docker_bash, text
 
     def dockerkillswitch_g_text(self):
         text = f"""#!/bin/bash
 {self.bashfunctions}
+{self.procfunctions}
 create_filter_chain 'RB_DOCKER_VPN_KILL_SWITCH'
 #port 443 https
 create_filter_rule 'iptables -A RB_DOCKER_VPN_KILL_SWITCH -o tun+ -p tcp --dport 443 -j ACCEPT'
@@ -515,5 +648,6 @@ create_filter_rule 'iptables -A RB_DOCKER_VPN_KILL_SWITCH -o tun+ -p icmp -j ACC
 create_filter_rule 'iptables -A RB_DOCKER_VPN_KILL_SWITCH  -i tun+ -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
 create_filter_rule 'iptables -A RB_DOCKER_VPN_KILL_SWITCH  -j DROP'
 create_filter_rule 'iptables -I DOCKER-USER  -j RB_DOCKER_VPN_KILL_SWITCH'
+sysctl_file_disable_ipv6
 """
         return self.systemdfilepaths.docker_bash, text
